@@ -5,14 +5,13 @@ use strict;
 use Rose::Object;
 our @ISA = qw(Rose::Object);
 
-our $VERSION = '0.02';
+our $VERSION = '0.60';
 
 use Rose::Object::MakeMethods::Generic
 (
   scalar => 
   [
     'error',
-    'total',
     '_count',
     '_next_code',
     '_finish_code',
@@ -42,6 +41,8 @@ sub DESTROY
   $self->finish  if($self->active);
 }
 
+sub total { shift->{'_count'} }
+
 1;
 
 __END__
